betty.test_utils.ancestry.place_type - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
Toggle table of contents sidebar

# Source code for betty.test_utils.ancestry.place_type

    """
    Test utilities for :py:mod:`betty.ancestry.place_type`.
    """

    from __future__ import annotations

    from betty.ancestry.place_type import PlaceType
    from betty.test_utils.plugin import (
        DummyPlugin,
        PluginTestBase,
    )

    class PlaceTypeTestBase(PluginTestBase[PlaceType]):
        """
        A base class for testing :py:class:`betty.ancestry.place_type.PlaceType` implementations.
        """

        pass

    class DummyPlaceType(DummyPlugin, PlaceType):
        """
        A dummy place type implementation.
        """

        pass